package com.bonus.canteen.core.kitchen.service;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceSensorMetric;

/**
 * 厨房设备衡量指标设置Service接口
 * 
 * @author xsheng
 * @date 2025-06-16
 */
public interface IKitchenDeviceSensorMetricService {
    /**
     * 查询厨房设备衡量指标设置
     * 
     * @param measureId 厨房设备衡量指标设置主键
     * @return 厨房设备衡量指标设置
     */
    public KitchenDeviceSensorMetric selectKitchenDeviceSensorMetricByMeasureId(Long measureId);

    /**
     * 查询厨房设备衡量指标设置列表
     * 
     * @param kitchenDeviceSensorMetric 厨房设备衡量指标设置
     * @return 厨房设备衡量指标设置集合
     */
    public List<KitchenDeviceSensorMetric> selectKitchenDeviceSensorMetricList(KitchenDeviceSensorMetric kitchenDeviceSensorMetric);

    /**
     * 新增厨房设备衡量指标设置
     * 
     * @param kitchenDeviceSensorMetric 厨房设备衡量指标设置
     * @return 结果
     */
    public int insertKitchenDeviceSensorMetric(KitchenDeviceSensorMetric kitchenDeviceSensorMetric);

    public int batchInsertKitchenDeviceSensorMetric(List<KitchenDeviceSensorMetric> kitchenDeviceSensorMetric);

    /**
     * 修改厨房设备衡量指标设置
     * 
     * @param kitchenDeviceSensorMetric 厨房设备衡量指标设置
     * @return 结果
     */
    public int updateKitchenDeviceSensorMetric(KitchenDeviceSensorMetric kitchenDeviceSensorMetric);

    public int batchUpdateKitchenDeviceSensorMetric(List<KitchenDeviceSensorMetric> list);

    public int rollbackKitchenDeviceSensorMetricByMeasureIds(Long[] measureIds);

    /**
     * 批量删除厨房设备衡量指标设置
     * 
     * @param measureIds 需要删除的厨房设备衡量指标设置主键集合
     * @return 结果
     */
    public int deleteKitchenDeviceSensorMetricByMeasureIds(Long[] measureIds);

    /**
     * 删除厨房设备衡量指标设置信息
     * 
     * @param measureId 厨房设备衡量指标设置主键
     * @return 结果
     */
    public int deleteKitchenDeviceSensorMetricByMeasureId(Long measureId);
}
