package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceSensorMetric;
import com.bonus.canteen.core.kitchen.service.IKitchenDeviceSensorMetricService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房设备衡量指标设置Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房设备衡量指标设置接口")
@RestController
@RequestMapping("/kitchen_device_sensor_metric")
public class KitchenDeviceSensorMetricController extends BaseController {
    @Autowired
    private IKitchenDeviceSensorMetricService kitchenDeviceSensorMetricService;

    /**
     * 查询厨房设备衡量指标设置列表
     */
    @ApiOperation(value = "查询厨房设备衡量指标设置列表")
    //@RequiresPermissions("kitchen:metric:list")
    @GetMapping("/list")
    public TableDataInfo list(KitchenDeviceSensorMetric kitchenDeviceSensorMetric) {
        startPage();
        List<KitchenDeviceSensorMetric> list = kitchenDeviceSensorMetricService.selectKitchenDeviceSensorMetricList(kitchenDeviceSensorMetric);
        return getDataTable(list);
    }

    /**
     * 导出厨房设备衡量指标设置列表
     */
    @ApiOperation(value = "导出厨房设备衡量指标设置列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:metric:export")
    @SysLog(title = "厨房设备衡量指标设置", businessType = OperaType.EXPORT, logType = 1,module = "厨房管理->导出厨房设备衡量指标设置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenDeviceSensorMetric kitchenDeviceSensorMetric) {
        List<KitchenDeviceSensorMetric> list = kitchenDeviceSensorMetricService.selectKitchenDeviceSensorMetricList(kitchenDeviceSensorMetric);
        ExcelUtil<KitchenDeviceSensorMetric> util = new ExcelUtil<KitchenDeviceSensorMetric>(KitchenDeviceSensorMetric.class);
        util.exportExcel(response, list, "厨房设备衡量指标设置数据");
    }

    /**
     * 获取厨房设备衡量指标设置详细信息
     */
    @ApiOperation(value = "获取厨房设备衡量指标设置详细信息")
    //@RequiresPermissions("kitchen:metric:query")
    @GetMapping(value = "/{measureId}")
    public AjaxResult getInfo(@PathVariable("measureId") Long measureId) {
        return success(kitchenDeviceSensorMetricService.selectKitchenDeviceSensorMetricByMeasureId(measureId));
    }

    /**
     * 新增厨房设备衡量指标设置
     */
    @ApiOperation(value = "新增厨房设备衡量指标设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:metric:add")
    @SysLog(title = "厨房设备衡量指标设置", businessType = OperaType.INSERT, logType = 1,module = "厨房管理->新增厨房设备衡量指标设置")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenDeviceSensorMetric kitchenDeviceSensorMetric) {
        try {
            return toAjax(kitchenDeviceSensorMetricService.insertKitchenDeviceSensorMetric(kitchenDeviceSensorMetric));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    @ApiOperation(value = "批量新增厨房设备衡量指标设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:metric:add")
    @SysLog(title = "厨房设备衡量指标设置", businessType = OperaType.INSERT, logType = 1,module = "厨房管理->批量新增厨房设备衡量指标设置")
    @PostMapping("/batchAdd")
    public AjaxResult batchAdd(@RequestBody List<KitchenDeviceSensorMetric> list) {
        try {
            return toAjax(kitchenDeviceSensorMetricService.batchInsertKitchenDeviceSensorMetric(list));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房设备衡量指标设置
     */
    @ApiOperation(value = "修改厨房设备衡量指标设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:metric:edit")
    @SysLog(title = "厨房设备衡量指标设置", businessType = OperaType.UPDATE, logType = 1,module = "厨房管理->修改厨房设备衡量指标设置")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenDeviceSensorMetric kitchenDeviceSensorMetric) {
        try {
            return toAjax(kitchenDeviceSensorMetricService.updateKitchenDeviceSensorMetric(kitchenDeviceSensorMetric));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    @ApiOperation(value = "批量修改厨房设备衡量指标设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:metric:edit")
    @SysLog(title = "厨房设备衡量指标设置", businessType = OperaType.UPDATE, logType = 1,module = "厨房管理->批量修改厨房设备衡量指标设置")
    @PostMapping("/batchEdit")
    public AjaxResult batchEdit(@RequestBody List<KitchenDeviceSensorMetric> list) {
        try {
            return toAjax(kitchenDeviceSensorMetricService.batchUpdateKitchenDeviceSensorMetric(list));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    @ApiOperation(value = "批量回滚厨房设备衡量指标设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:metric:remove")
    @SysLog(title = "厨房设备衡量指标设置", businessType = OperaType.DELETE, logType = 1,module = "厨房管理->批量回滚厨房设备衡量指标设置")
    @PostMapping("/rollback/{measureIds}")
    public AjaxResult rollback(@PathVariable Long[] measureIds) {
        return toAjax(kitchenDeviceSensorMetricService.rollbackKitchenDeviceSensorMetricByMeasureIds(measureIds));
    }

    /**
     * 删除厨房设备衡量指标设置
     */
    @ApiOperation(value = "删除厨房设备衡量指标设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:metric:remove")
    @SysLog(title = "厨房设备衡量指标设置", businessType = OperaType.DELETE, logType = 1,module = "厨房管理->删除厨房设备衡量指标设置")
	@PostMapping("/del/{measureIds}")
    public AjaxResult remove(@PathVariable Long[] measureIds) {
        return toAjax(kitchenDeviceSensorMetricService.deleteKitchenDeviceSensorMetricByMeasureIds(measureIds));
    }
}
